==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/bedget/controller/QuotaanalysisController.java <==
package com.ejianc.business.bedget.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.bedget.bean.QuotaanalysisdetailEntity;
import com.ejianc.business.bedget.bean.QuotaanalysisdetailInnateEntity;
import com.ejianc.business.bedget.service.IQuotaanalysisdetailInnateService;
import com.ejianc.business.bedget.vo.QuotaanalysisdetailVO;
import com.ejianc.business.record.bean.RecordQuotaanalysisEntity;
import com.ejianc.business.record.service.IRecordQuotaanalysisService;
import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.utils.DateUtils;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.bedget.bean.QuotaanalysisEntity;
import com.ejianc.business.bedget.service.IQuotaanalysisService;
import com.ejianc.business.bedget.vo.QuotaanalysisVO;

/**
 * 限额设计指标分析
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("quotaanalysis")
public class QuotaanalysisController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IQuotaanalysisdetailInnateService quotaanalysisdetailInnateService;

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IQuotaanalysisService service;
    @Autowired
    private IRecordQuotaanalysisService recordQuotaanalysisService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<QuotaanalysisVO> saveOrUpdate(@RequestBody QuotaanalysisVO saveorUpdateVO) {
    	QuotaanalysisEntity entity = BeanMapper.map(saveorUpdateVO, QuotaanalysisEntity.class);

        QueryWrapper<QuotaanalysisEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("project_id", entity.getProjectId());
        queryWrapper.eq("dr", "0");
        if(saveorUpdateVO.getId() != null && saveorUpdateVO.getId() != 0){
            queryWrapper.ne("id", saveorUpdateVO.getId());
        }
        List<QuotaanalysisEntity> pro = service.list(queryWrapper);

        if(pro.size() > 0){
            throw new BusinessException("该项目已经创建一个限额设计指标分析，不允许重复创建!");
        }

    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
                entity.setChangeState("1");//未变更
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        List<QuotaanalysisdetailEntity> children = entity.getQuotaanalysisdetailEntities();
        for (int i = 0; i < children.size(); i++) {
            QuotaanalysisdetailEntity quotaanalysisdetail = children.get(i);
            quotaanalysisdetail.setSort(String.valueOf(i + 1));
        }
    	service.saveOrUpdate(entity, false);
    	QuotaanalysisVO vo = BeanMapper.map(entity, QuotaanalysisVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<QuotaanalysisVO> queryDetail(Long id) {
    	QuotaanalysisEntity entity = service.selectById(id);
    	QuotaanalysisVO vo = BeanMapper.map(entity, QuotaanalysisVO.class);

        List<QuotaanalysisdetailVO> voList = vo.getQuotaanalysisdetailEntities();
        if(voList != null && voList.size() > 0){
            //按序号排序
            Collections.sort(voList, new Comparator<QuotaanalysisdetailVO>() {
                @Override
                public int compare(QuotaanalysisdetailVO o1, QuotaanalysisdetailVO o2) {
                    return Integer.parseInt(o1.getSort()) - (Integer.parseInt(o2.getSort()));
                }
            });
        }

        //当前单据变更过则显示变更记录
        if(!"1".equals(vo.getChangeState())){
            QueryWrapper<RecordQuotaanalysisEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("dr", 0);
            queryWrapper.eq("original_id", vo.getId());
            List<RecordQuotaanalysisEntity> records = recordQuotaanalysisService.list(queryWrapper);
            if(records!=null&&records.size()>0){
                vo.setRecordQuotaanalysisList(BeanMapper.mapList(records, RecordQuotaanalysisVO.class));
            }
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description queryDetail 查询该项目是否已有限额设计指标分析单据
     * @param id
     * @param projectId
     */
    @RequestMapping(value = "/queryProject", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> queryProject(Long id, Long projectId) {
        QueryWrapper<QuotaanalysisEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("dr", 0);
        queryWrapper.eq("project_id", projectId);
        if(id != null && id != 0){
            queryWrapper.ne("id", id);
        }
        List<QuotaanalysisEntity> entityList = service.list(queryWrapper);

        if(entityList.size() > 0){
            return CommonResponse.success("该项目已经创建一个限额设计指标分析，请选择其他项目!", "0");
        }

        return CommonResponse.success("查询成功！", "1");
    }

    /**
     * @Description queryInnateColumns 查询固定列
     * @param
     */
    @RequestMapping(value = "/queryInnateColumns", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<QuotaanalysisdetailInnateEntity>> queryInnateColumns() {
        //查询固定列
        QueryWrapper<QuotaanalysisdetailInnateEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("dr", "0");
        queryWrapper.orderByAsc("id");
        List<QuotaanalysisdetailInnateEntity> pro = quotaanalysisdetailInnateService.list(queryWrapper);
        return CommonResponse.success("查询固定列数据成功！",pro);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<QuotaanalysisVO> vos) {
        service.removeByIds(vos.stream().map(QuotaanalysisVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<QuotaanalysisVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("project_name");
        fuzzyFields.add("operator_name");
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<QuotaanalysisEntity> page = service.queryPage(param,false);
        IPage<QuotaanalysisVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), QuotaanalysisVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("project_name");
        fuzzyFields.add("operator_name");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<QuotaanalysisEntity> list = service.queryList(param);
        //时间转换
        List<QuotaanalysisVO> quotaanalysisVOList = BeanMapper.mapList(list, QuotaanalysisVO.class);
        for (int i = 0; i < quotaanalysisVOList.size(); i++) {
            QuotaanalysisVO quotaanalysisVO = quotaanalysisVOList.get(i);
            quotaanalysisVO.setSort(String.valueOf(i+1));
            if (quotaanalysisVO.getCreateTime()!=null){
                quotaanalysisVO.setCreateTimeShow(DateUtils.dateSimple2(quotaanalysisVO.getCreateTime()));
            }

            String billStateStr = quotaanalysisVO.getBillState().toString();
            String changeState = quotaanalysisVO.getChangeState();
            if (billStateStr != null){
                if("0".equals(billStateStr)){//自由态
                    billStateStr = "自由态";
                }else if("1".equals(billStateStr)){//已提交
                    billStateStr = "已提交";
                }else if("2".equals(billStateStr) || "5".equals(billStateStr)){//审批中
                    billStateStr = "审批中";
                }else if("3".equals(billStateStr)){//审批通过
                    billStateStr = "审批通过";
                }else if("4".equals(billStateStr)){//驳回
                    billStateStr = "驳回";
                }

                quotaanalysisVO.setBillStateStr(billStateStr);
            }

            if (changeState != null){
                if("1".equals(changeState)){//1:未变更
                    changeState = "未变更";
                }else if("2".equals(changeState)){//2:变更中
                    changeState = "变更中";
                }else if("3".equals(changeState)){//3:已变更
                    changeState = "已变更";
                }

                quotaanalysisVO.setChangeState(changeState);
            }
        }
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", quotaanalysisVOList);
        ExcelExport.getInstance().export("QuotaanalysisMain-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refQuotaanalysisData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<QuotaanalysisVO>> refQuotaanalysisData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<QuotaanalysisEntity> page = service.queryPage(param,false);
        IPage<QuotaanalysisVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), QuotaanalysisVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/bedget/controller/QuotaanalysisController.java <==
package com.ejianc.business.bedget.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.bedget.bean.QuotaanalysisEntity;
import com.ejianc.business.bedget.bean.QuotaanalysisdetailEntity;
import com.ejianc.business.bedget.bean.QuotaanalysisdetailInnateEntity;
import com.ejianc.business.bedget.service.IQuotaanalysisService;
import com.ejianc.business.bedget.service.IQuotaanalysisdetailInnateService;
import com.ejianc.business.bedget.vo.QuotaanalysisVO;
import com.ejianc.business.bedget.vo.QuotaanalysisdetailVO;
import com.ejianc.business.record.bean.RecordQuotaanalysisEntity;
import com.ejianc.business.record.service.IRecordQuotaanalysisService;
import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.utils.DateUtils;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 限额设计指标分析
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("quotaanalysis")
public class QuotaanalysisController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IQuotaanalysisdetailInnateService quotaanalysisdetailInnateService;

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    @Autowired
    private SessionManager sessionManager;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IQuotaanalysisService service;
    @Autowired
    private IRecordQuotaanalysisService recordQuotaanalysisService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<QuotaanalysisVO> saveOrUpdate(@RequestBody QuotaanalysisVO saveorUpdateVO) {
    	QuotaanalysisEntity entity = BeanMapper.map(saveorUpdateVO, QuotaanalysisEntity.class);

        QueryWrapper<QuotaanalysisEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("project_id", entity.getProjectId());
        queryWrapper.eq("dr", "0");
        if(saveorUpdateVO.getId() != null && saveorUpdateVO.getId() != 0){
            queryWrapper.ne("id", saveorUpdateVO.getId());
        }
        List<QuotaanalysisEntity> pro = service.list(queryWrapper);

        if(pro.size() > 0){
            throw new BusinessException("该项目已经创建一个限额设计指标分析，不允许重复创建!");
        }

    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
                entity.setChangeState("1");//未变更
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        List<QuotaanalysisdetailEntity> children = entity.getQuotaanalysisdetailEntities();
        for (int i = 0; i < children.size(); i++) {
            QuotaanalysisdetailEntity quotaanalysisdetail = children.get(i);
            quotaanalysisdetail.setSort(String.valueOf(i + 1));
        }
    	service.saveOrUpdate(entity, false);
    	QuotaanalysisVO vo = BeanMapper.map(entity, QuotaanalysisVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<QuotaanalysisVO> queryDetail(Long id) {
    	QuotaanalysisEntity entity = service.selectById(id);
    	QuotaanalysisVO vo = BeanMapper.map(entity, QuotaanalysisVO.class);

        List<QuotaanalysisdetailVO> voList = vo.getQuotaanalysisdetailEntities();
        if(voList != null && voList.size() > 0){
            //按序号排序
            Collections.sort(voList, new Comparator<QuotaanalysisdetailVO>() {
                @Override
                public int compare(QuotaanalysisdetailVO o1, QuotaanalysisdetailVO o2) {
                    return Integer.parseInt(o1.getSort()) - (Integer.parseInt(o2.getSort()));
                }
            });
        }

        //当前单据变更过则显示变更记录
        if(!"1".equals(vo.getChangeState())){
            QueryWrapper<RecordQuotaanalysisEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("dr", 0);
            queryWrapper.eq("original_id", vo.getId());
            List<RecordQuotaanalysisEntity> records = recordQuotaanalysisService.list(queryWrapper);
            if(records!=null&&records.size()>0){
                vo.setRecordQuotaanalysisList(BeanMapper.mapList(records, RecordQuotaanalysisVO.class));
            }
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description queryDetail 查询该项目是否已有限额设计指标分析单据
     * @param id
     * @param projectId
     */
    @RequestMapping(value = "/queryProject", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> queryProject(Long id, Long projectId) {
        QueryWrapper<QuotaanalysisEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("dr", 0);
        queryWrapper.eq("project_id", projectId);
        if(id != null && id != 0){
            queryWrapper.ne("id", id);
        }
        List<QuotaanalysisEntity> entityList = service.list(queryWrapper);

        if(entityList.size() > 0){
            return CommonResponse.success("该项目已经创建一个限额设计指标分析，请选择其他项目!", "0");
        }

        return CommonResponse.success("查询成功！", "1");
    }

    /**
     * @Description queryInnateColumns 查询固定列
     * @param
     */
    @RequestMapping(value = "/queryInnateColumns", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<QuotaanalysisdetailInnateEntity>> queryInnateColumns() {
        //查询固定列
        QueryWrapper<QuotaanalysisdetailInnateEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("dr", "0");
        queryWrapper.orderByAsc("id");
        List<QuotaanalysisdetailInnateEntity> pro = quotaanalysisdetailInnateService.list(queryWrapper);
        return CommonResponse.success("查询固定列数据成功！",pro);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<QuotaanalysisVO> vos) {
        service.removeByIds(vos.stream().map(QuotaanalysisVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<QuotaanalysisVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("project_name");
        fuzzyFields.add("operator_name");
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        IPage<QuotaanalysisEntity> page = service.queryPage(param,false);
        IPage<QuotaanalysisVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), QuotaanalysisVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }



    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }



    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("project_name");
        fuzzyFields.add("operator_name");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        List<QuotaanalysisEntity> list = service.queryList(param);
        //时间转换
        List<QuotaanalysisVO> quotaanalysisVOList = BeanMapper.mapList(list, QuotaanalysisVO.class);
        for (int i = 0; i < quotaanalysisVOList.size(); i++) {
            QuotaanalysisVO quotaanalysisVO = quotaanalysisVOList.get(i);
            quotaanalysisVO.setSort(String.valueOf(i+1));
            if (quotaanalysisVO.getCreateTime()!=null){
                quotaanalysisVO.setCreateTimeShow(DateUtils.dateSimple2(quotaanalysisVO.getCreateTime()));
            }

            String billStateStr = quotaanalysisVO.getBillState().toString();
            String changeState = quotaanalysisVO.getChangeState();
            if (billStateStr != null){
                if("0".equals(billStateStr)){//自由态
                    billStateStr = "自由态";
                }else if("1".equals(billStateStr)){//已提交
                    billStateStr = "已提交";
                }else if("2".equals(billStateStr) || "5".equals(billStateStr)){//审批中
                    billStateStr = "审批中";
                }else if("3".equals(billStateStr)){//审批通过
                    billStateStr = "审批通过";
                }else if("4".equals(billStateStr)){//驳回
                    billStateStr = "驳回";
                }

                quotaanalysisVO.setBillStateStr(billStateStr);
            }

            if (changeState != null){
                if("1".equals(changeState)){//1:未变更
                    changeState = "未变更";
                }else if("2".equals(changeState)){//2:变更中
                    changeState = "变更中";
                }else if("3".equals(changeState)){//3:已变更
                    changeState = "已变更";
                }

                quotaanalysisVO.setChangeState(changeState);
            }
        }
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", quotaanalysisVOList);
        ExcelExport.getInstance().export("QuotaanalysisMain-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refQuotaanalysisData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<QuotaanalysisVO>> refQuotaanalysisData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<QuotaanalysisEntity> page = service.queryPage(param,false);
        IPage<QuotaanalysisVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), QuotaanalysisVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
